@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -29,26 +30,18 @@
 #include "precompiled_svtools.hxx"
 #include <svtools/editbrowsebox.hxx>
 
-#ifndef _SVTOOLS_EDITBROWSEBOX_HRC_
 #include "editbrowsebox.hrc"
-#endif
 
-#ifndef _APP_HXX //autogen
 #include <vcl/svapp.hxx>
-#endif
 #include <tools/debug.hxx>
 #include <vcl/window.hxx>
 
-#ifndef _EDIT_HXX //autogen
 #include <vcl/edit.hxx>
-#endif
 #include <tools/resid.hxx>
 #include <vcl/spinfld.hxx>
 #include <svtools/svtdata.hxx>
 
-#ifndef _SVTOOLS_HRC
 #include <svtools/svtools.hrc>
-#endif
 
 #include <algorithm>
 #include <tools/multisel.hxx>
@@ -1435,3 +1428,4 @@ namespace svt
 }	// namespace svt
 // .......................................................................
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
