@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,9 +29,7 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_toolkit.hxx"
 
-#ifndef _TOOLKIT_ROADMAP_CONTROL_HXX
 #include <toolkit/controls/roadmapcontrol.hxx>
-#endif
 #include <toolkit/helper/unopropertyarrayhelper.hxx>
 #include <toolkit/helper/property.hxx>
 #include <com/sun/star/awt/XVclWindowPeer.hpp>
@@ -497,3 +496,4 @@ void SAL_CALL UnoRoadmapControl::propertyChange( const PropertyChangeEvent& evt
 
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
