@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -432,6 +433,7 @@ ImplStyleData::ImplStyleData()
     mnAutoMnemonic				= 1;
     mnToolbarIconSize			= STYLE_TOOLBAR_ICONSIZE_UNKNOWN;
     mnSymbolsStyle				= STYLE_SYMBOLS_AUTO;
+    mnUseImagesInMenus			= STYLE_MENUIMAGES_AUTO;
     mnPreferredSymbolsStyle			= STYLE_SYMBOLS_AUTO;
     mpFontOptions              = NULL;
 
@@ -536,6 +538,7 @@ ImplStyleData::ImplStyleData( const ImplStyleData& rData ) :
     mnUseFlatMenues 			= rData.mnUseFlatMenues;
     mnAutoMnemonic				= rData.mnAutoMnemonic;
     mnUseImagesInMenus			= rData.mnUseImagesInMenus;
+    mbPreferredUseImagesInMenus	= rData.mbPreferredUseImagesInMenus;
     mnSkipDisabledInMenus		= rData.mnSkipDisabledInMenus;
     mnToolbarIconSize			= rData.mnToolbarIconSize;
     mnSymbolsStyle				= rData.mnSymbolsStyle;
@@ -629,7 +632,7 @@ void ImplStyleData::SetStandardStyles()
     mnUseSystemUIFonts			= 1;
     mnUseFlatBorders 			= 0;
     mnUseFlatMenues 			= 0;
-    mnUseImagesInMenus			= (USHORT)TRUE;
+    mbPreferredUseImagesInMenus	= TRUE;
     mnSkipDisabledInMenus		= (USHORT)FALSE;
 
     Gradient aGrad( GRADIENT_LINEAR, DEFAULT_WORKSPACE_GRADIENT_START_COLOR, DEFAULT_WORKSPACE_GRADIENT_END_COLOR );
@@ -702,35 +705,35 @@ void StyleSettings::Set3DColors( const Color& rColor )
 {
     switch ( nStyle )
     {
-        case STYLE_SYMBOLS_DEFAULT:    return ::rtl::OUString::createFromAscii( "default" );
-        case STYLE_SYMBOLS_HICONTRAST: return ::rtl::OUString::createFromAscii( "hicontrast" );
-        case STYLE_SYMBOLS_INDUSTRIAL: return ::rtl::OUString::createFromAscii( "tango" ); // industrial is dead
-        case STYLE_SYMBOLS_CRYSTAL:    return ::rtl::OUString::createFromAscii( "crystal" );
-        case STYLE_SYMBOLS_TANGO:      return ::rtl::OUString::createFromAscii( "tango" );
-        case STYLE_SYMBOLS_OXYGEN:     return ::rtl::OUString::createFromAscii( "oxygen" );
-        case STYLE_SYMBOLS_CLASSIC:    return ::rtl::OUString::createFromAscii( "classic" );
+        case STYLE_SYMBOLS_DEFAULT:    return ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("default"));
+        case STYLE_SYMBOLS_HICONTRAST: return ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("hicontrast"));
+        case STYLE_SYMBOLS_INDUSTRIAL: return ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("tango")); // industrial is dead
+        case STYLE_SYMBOLS_CRYSTAL:    return ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("crystal"));
+        case STYLE_SYMBOLS_TANGO:      return ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("tango"));
+        case STYLE_SYMBOLS_OXYGEN:     return ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("oxygen"));
+        case STYLE_SYMBOLS_CLASSIC:    return ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("classic"));
     }
 
-    return ::rtl::OUString::createFromAscii( "auto" );
+    return ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("auto"));
 }
 
 // -----------------------------------------------------------------------
 
 ULONG StyleSettings::ImplNameToSymbolsStyle( const ::rtl::OUString &rName ) const
 {
-    if ( rName == ::rtl::OUString::createFromAscii( "default" ) )
+    if ( rName == ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("default")) )
         return STYLE_SYMBOLS_DEFAULT;
-    else if ( rName == ::rtl::OUString::createFromAscii( "hicontrast" ) )
+    else if ( rName == ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("hicontrast")) )
         return STYLE_SYMBOLS_HICONTRAST;
-    else if ( rName == ::rtl::OUString::createFromAscii( "industrial" ) )
+    else if ( rName == ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("industrial")) )
         return STYLE_SYMBOLS_TANGO; // industrial is dead
-    else if ( rName == ::rtl::OUString::createFromAscii( "crystal" ) )
+    else if ( rName == ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("crystal")) )
         return STYLE_SYMBOLS_CRYSTAL;
-    else if ( rName == ::rtl::OUString::createFromAscii( "tango" ) )
+    else if ( rName == ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("tango")) )
         return STYLE_SYMBOLS_TANGO;
-    else if ( rName == ::rtl::OUString::createFromAscii( "oxygen" ) )
+    else if ( rName == ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("oxygen")) )
         return STYLE_SYMBOLS_OXYGEN;
-    else if ( rName == ::rtl::OUString::createFromAscii( "classic" ) )
+    else if ( rName == ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("classic")) )
         return STYLE_SYMBOLS_CLASSIC;
 
     return STYLE_SYMBOLS_AUTO;
@@ -867,6 +870,19 @@ bool StyleSettings::CheckSymbolStyle( ULONG nStyle ) const
 
 // -----------------------------------------------------------------------
 
+BOOL StyleSettings::GetUseImagesInMenus() const
+{
+    // icon mode selected in Tools -> Options... -> OpenOffice.org -> View
+    USHORT nStyle = mpData->mnUseImagesInMenus;
+
+    if ( nStyle == STYLE_MENUIMAGES_AUTO )
+        return GetPreferredUseImagesInMenus();
+
+    return (BOOL)nStyle;
+}
+
+// -----------------------------------------------------------------------
+
 void StyleSettings::SetStandardStyles()
 {
     CopyData();
@@ -1103,6 +1119,7 @@ BOOL StyleSettings::operator ==( const StyleSettings& rSet ) const
          (mpData->maFieldFont               == rSet.mpData->maFieldFont)                &&
          (mpData->maIconFont                == rSet.mpData->maIconFont)					&&
          (mpData->mnUseImagesInMenus		== rSet.mpData->mnUseImagesInMenus)			&&
+         (mpData->mbPreferredUseImagesInMenus == rSet.mpData->mbPreferredUseImagesInMenus) &&
          (mpData->mnSkipDisabledInMenus		== rSet.mpData->mnSkipDisabledInMenus)		&&
          (mpData->maFontColor				== rSet.mpData->maFontColor ))
         return TRUE;
@@ -1930,11 +1947,11 @@ BOOL AllSettings::GetLayoutRTL() const
         nUIMirroring = 0; // ask configuration only once
         utl::OConfigurationNode aNode = utl::OConfigurationTreeRoot::tryCreateWithServiceFactory(
             vcl::unohelper::GetMultiServiceFactory(),
-            OUString::createFromAscii( "org.openoffice.Office.Common/I18N/CTL" ) );    // note: case sensisitive !
+            OUString(RTL_CONSTASCII_USTRINGPARAM("org.openoffice.Office.Common/I18N/CTL")) );    // note: case sensisitive !
         if ( aNode.isValid() )
         {
             BOOL bTmp = BOOL();
-            ::com::sun::star::uno::Any aValue = aNode.getNodeValue( OUString::createFromAscii( "UIMirroring" ) );
+            ::com::sun::star::uno::Any aValue = aNode.getNodeValue( OUString(RTL_CONSTASCII_USTRINGPARAM("UIMirroring")) );
             if( aValue >>= bTmp )
             {
                 // found true or false; if it was nil, nothing is changed
@@ -2082,3 +2099,5 @@ void AllSettings::LocaleSettingsChanged( sal_uInt32 nHint )
 
     Application::SetSettings( aAllSettings );
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
