@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,9 +31,7 @@
 #include <tools/list.hxx>
 #include <tools/debug.hxx>
 
-#ifndef _SV_RC_H
 #include <tools/rc.h>
-#endif
 #include <vcl/svdata.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/help.hxx>
@@ -2435,3 +2434,5 @@ void ToolBox::SetImageListProvider(vcl::IImageListProvider* _pProvider)
     ImplUpdateImageList();
 }
 // -----------------------------------------------------------------------
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
