@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -224,22 +225,10 @@ void X11SalGraphics::SetDrawable( Drawable aDrawable, int nScreen )
 
 void X11SalGraphics::Init( SalFrame *pFrame, Drawable aTarget, int nScreen )
 {
-#if 0 // TODO: use SetDrawable() instead
-    m_pColormap		= &GetX11SalData()->GetDisplay()->GetColormap(nScreen);
-    hDrawable_		= aTarget;
-    m_nScreen       = nScreen;
-    SetXRenderFormat( NULL );
-    if( m_aRenderPicture )
-        XRenderPeer::GetInstance().FreePicture( m_aRenderPicture ), m_aRenderPicture = 0;
 
-    nPenPixel_		= GetPixel( nPenColor_ );
-    nTextPixel_ 	= GetPixel( nTextColor_ );
-    nBrushPixel_	= GetPixel( nBrushColor_ );
-#else
     m_pColormap		= &GetX11SalData()->GetDisplay()->GetColormap(nScreen);
     m_nScreen = nScreen;
     SetDrawable( aTarget, nScreen );
-#endif
 
     bWindow_		= TRUE;
     m_pFrame		= pFrame;
@@ -1035,29 +1024,14 @@ XID X11SalGraphics::GetXRenderPicture()
     if( !m_aRenderPicture )
     {
         // check xrender support for matching visual
-        // find a XRenderPictFormat compatible with the Drawable
         XRenderPictFormat* pVisualFormat = static_cast<XRenderPictFormat*>(GetXRenderFormat());
         if( !pVisualFormat )
-        {
-            Visual* pVisual = GetDisplay()->GetVisual( m_nScreen ).GetVisual();
-            pVisualFormat = rRenderPeer.FindVisualFormat( pVisual );
-            if( !pVisualFormat )
-                return 0;
-            // cache the XRenderPictFormat
-            SetXRenderFormat( static_cast<void*>(pVisualFormat) );
-        }
+            return 0;
 
         // get the matching xrender target for drawable
         m_aRenderPicture = rRenderPeer.CreatePicture( hDrawable_, pVisualFormat, 0, NULL );
     }
 
-#if 0
-    // setup clipping so the callers don't have to do it themselves
-    // TODO: avoid clipping if already set correctly
-    if( pClipRegion_ && !XEmptyRegion( pClipRegion_ ) )
-        rRenderPeer.SetPictureClipRegion( aDstPic, pClipRegion_ );
-    else
-#endif
     {
         // reset clip region
         // TODO: avoid clip reset if already done
@@ -1069,6 +1043,13 @@ XID X11SalGraphics::GetXRenderPicture()
     return m_aRenderPicture;
 }
 
+void* X11SalGraphics::GetXRenderFormat() const
+{
+    if( m_pRenderFormat == NULL )
+        const_cast<X11SalGraphics*>(this)->m_pRenderFormat = XRenderPeer::GetInstance().FindVisualFormat( GetVisual().visual );
+    return m_pRenderFormat;
+}
+
 // -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 
 SystemGraphicsData X11SalGraphics::GetGraphicsData() const
@@ -1287,3 +1268,4 @@ bool X11SalGraphics::drawPolyLine(const ::basegfx::B2DPolygon& rPolygon, double
 
 // -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
