@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -37,9 +38,7 @@
 #include <excpt.h>
 #endif
 
-#ifndef _OSL_MODULE_H
 #include <osl/module.h>
-#endif
 #include <wincomp.hxx>
 #include <saldata.hxx>
 #include <salinst.h>
@@ -2364,3 +2363,5 @@ ULONG WinSalPrinter::GetErrorCode()
 {
     return mnError;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
